package
Version:
v0.2.2
Opens a new window with list of versions in this module.
Published: Aug 21, 2026
License: MIT
Opens a new window with license information.
Imports: 19
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Result struct {
Installed string `json:"installed"`
Latest string `json:"latest"`
Current bool `json:"current"`
Updated bool `json:"updated"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.